import React, { useEffect, useState } from 'react'
import SiteModal from '@/components/Modal/SiteModa';
import { Checkbox, Input, Button } from 'antd'
import { data } from './Mock'
import _ from 'lodash';
import classnames from 'classnames';
import styles from './VisibleRoleModal.less'


const checkIsGroup = node =>
    node.children?.length > 0;
const getId = item =>
    item.userID || item.roleID || item.stationID || item.id;

const VisibleRoleModal = props => {


    const [loading, setLoading] = useState(false);
    
    const onSubmit = () => { }
    return (
        <SiteModal
            {...props}
            title="编辑推送方案"
            bodyStyle={{ width: '100%', minHeight: '100px' }}
            style={{ top: 200, borderRadius: '20px' }}
            width="800px"
            destroyOnClose
            cancelText="取消"
            okText="确认"
            onOk={() => onSubmit()}
            confirmLoading={loading}
        >
            <div>
                <ListCard />
            </div>
        </SiteModal>
    )
}
const checkChildrenByCondition = (
    item,
    fn,
    withGroup = true,
    method = 'every',
) => {
    if (item.children && item.children.length > 0) {
        return fn(item);
    }
    const childrenResults = item.children[method](t =>
        checkChildrenByCondition(t, fn, withGroup, method),
    );
    return withGroup ? [fn(item), ...childrenResults] : [...childrenResults];
};
const ListCard = props => {


    const { onChange } = props

    const [changedItem, setChangedItem] = useState({ item: {} });
    const [valueList, setValueList] = useState([]);
    const checkAll = e => {
        if (e.target.checked) {
            const result = data.map(item => getAllID(item)).flat(Infinity);
            setValueList(result);
            // eslint-disable-next-line no-unused-expressions
            onChange && onChange(result);
        } else {
            setValueList([]);
            // eslint-disable-next-line no-unused-expressions
            onChange && onChange([]);
        }
    };

    const getAllID = item => {
        let result = [];
        const haveChildren =
            Array.isArray(item.children) && item.children.length > 0;
        // 统一使用 getId
        result.push(getId(item));
        if (haveChildren) {
            // 每次递归result被置空，所以要另外保存
            result = [...item.children.map(i => getAllID(i)), ...result];
        }
        return result;
    };

    const updateValueList = (checkedKeys, childrenKeys, sourceItem) => {
        const removekeys = _.difference(childrenKeys, checkedKeys);
        let result = _.uniq(_.union(checkedKeys, valueList));
        _.remove(result, v => removekeys.includes(v));
        setValueList(result);
        if (sourceItem) setChangedItem(sourceItem);
        // eslint-disable-next-line no-unused-expressions
        onChange && onChange(result);
    }

    useEffect(() => {
        setValueList(['1', '2', '3'])
    }, [])
    return (
        <div>
            <Checkbox onChange={checkAll}>全选/全不选</Checkbox>
            {
                data.map((item, i) => {
                    return <ListCardItem
                        key={i}
                        item={item}
                        updateValueList={updateValueList}
                        valueList={valueList}
                        changedItem={changedItem}
                        {...props}
                    />
                })
            }


        </div>
    )
}
const ListCardItem = props => {
    const {
        item,
        valueList,
        updateValueList,
        changedItem
    } = props;
    const id = item.id;
    // 当前组件是否是分组id
    const isGroup = item.children && item.children.length > 0;
    const [indeterminate, setIndeterminate] = useState(!isGroup);
    const [childrenKeys, setChildrenKeys] = useState([]);

    useEffect(() => {
        if (isGroup) {
            const keys = item.children
                .map(child =>
                    checkChildrenByCondition(child, c => c.id, true, 'map'),
                )
                .flat(Infinity);
            setChildrenKeys(keys);
        } else {
            //
        }
    }, [item]);

    useEffect(() => {
        // 子节点勾选状态变化时
        if (
            isGroup &&
            changedItem.item !== item &&
            !checkIsGroup(changedItem.item) &&
            childrenKeys.includes(getId(changedItem.item))
        ) {
            if (changedItem.value && childrenKeys.every(c => valueList.includes(c))) {
                // 全选
                updateValueList([id], [id]);
                setIndeterminate(false);
            } else if (childrenKeys.some(c => valueList.includes(c))) {
                // 半选
                // eslint-disable-next-line no-unused-expressions
                valueList.includes(id) && updateValueList([], [id]);
                setIndeterminate(true);
            } else {
                // 零选
                // eslint-disable-next-line no-unused-expressions
                valueList.includes(id) && updateValueList([], [id]);
                setIndeterminate(false);
            }
        }
    }, [changedItem.item, changedItem.value]);


    const handleChecked = e => {
        const { checked: v } = e.target;
        if (isGroup) {
            const result = [...childrenKeys, id];
            updateValueList(v ? result : [], result, { item, value: v });
            setIndeterminate(false);
        } else {
            updateValueList(v ? [id] : [], [id], { item, value: v });
        }
    }
    const renderChild = () =>
        item.children &&
        item.children.map((c, i) => (
            <ListCardItem
                item={c}
                key={`item${i}key`}
                updateValueList={updateValueList}
                valueList={valueList}
                changedItem={changedItem}
            />
        ));
    return (
        <div className={classnames({
            [styles.divBox]: isGroup,
            [styles.divSingle]: !isGroup,
        })}>
            <div className={styles.topCheckbox}>
                <Checkbox
                    indeterminate={isGroup ? indeterminate : false}
                    checked={valueList.includes(id)}
                    onChange={handleChecked} >
                    {item.name}
                </Checkbox>
                <div style={{ width: '100%' }} className={styles.checkdiv}>
                    {
                        renderChild()
                    }
                </div>

            </div>

        </div>
    )
}
export default VisibleRoleModal