import qs from 'qs';
import { CITY_SERVICE, get, PUBLISH_SERVICE, post, postForm } from '../index';

/**
 * 获取所有网站配置
 * @param {*} userMode
 */
export const getWebModuleTree = userMode =>
  get(
    `${PUBLISH_SERVICE}/PlatformCenter/WebModuleTree?${qs.stringify({
      userMode,
    })}`,
  );

/**
 *  获取主题下拉选项
 */
export const getWebThemes = () =>
  get(`${CITY_SERVICE}/OMS.svc/W4_GetThemes`, { query: '' });

/**
 * 获取登录模板下拉选项
 */
export const getLoginPage = () =>
  get(`${CITY_SERVICE}/OMS.svc/W4_GetLoginPage`, { query: '' });

/**
 * 获取地图配置下拉选项
 */
export const getMapCofigs = () =>
  get(
    `${CITY_SERVICE}/OMS.svc/GetAllConfigText?terminalType=scheme&isBaseMap=false`,
    { query: '' },
  );

/**
 *  获取网站配置
 * @param {*} title 网站标题
 */
export const getWebconfig = title =>
  get(`${CITY_SERVICE}/OMS.svc/W4_GetWebsite`, { title });

/**
 * 编辑或添加网站。默认编辑模式
 * @param {*} config 网站配置
 * @param {*} isAdd true：添加  false：编辑
 */
export const postEditWebConfig = (config, isAdd = false) => {
  const obj = { ...config };
  Object.keys(obj).forEach(k => {
    if (typeof obj[k] === 'string') {
      obj[k] = obj[k].trim();
    }
  });
  return post(
    `${CITY_SERVICE}/OMS.svc/${
      isAdd ? 'W4_AddWebsite' : 'W4_EditWebsite'
    }?_version=9999`,
    qs.stringify({ config: JSON.stringify(obj) }),
    {
      headers: {
        'content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
      },
    },
  );
};

export const postAddWebSite = config => postEditWebConfig(config, true);

export const deleteWebsite = client =>
  get(`${CITY_SERVICE}/OMS.svc/W4_DeleteWebsite?_version=9999`, { client });

/**
 * 获取配置文件下拉选项
 */
export const getAllConfigName = () =>
  get(`${CITY_SERVICE}/OMS.svc/W4_GetAllConfigName?_version=9999`);

export const addWebMenu = param => {
  const defaultConfig = { pageUrl: '' };
  // eslint-disable-next-line no-return-assign
  Object.keys(param).forEach(k => (defaultConfig[k] = param[k]));
  return get(`${CITY_SERVICE}/OMS.svc/W4_AddMenu?_version=9999`, defaultConfig);
};

export const editWebMenu = param =>
  get(`${CITY_SERVICE}/OMS.svc/W4_EditMenu?_version=9999`, param);

export const pEditWebMenu = param =>
  get(`${CITY_SERVICE}/OMS.svc/P_EditMenu?_version=9999`, param);

export const deleteWebMenu = param =>
  get(`${CITY_SERVICE}/OMS.svc/W4_DeleteMenu?_version=9999`, param);

export const getWebMenuInfo = param =>
  get(`${CITY_SERVICE}/OMS.svc/P_GetMenuInfo?_version=9999`, param);

export const saveConfigContent = (fileName, content) =>
  post(
    `${CITY_SERVICE}/OMS.svc/W4_SaveConfigContent?_version=9999&fileName=${fileName}`,
    qs.stringify({ web4ConfigContent: content }),
    {
      headers: {
        'content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
      },
    },
  );

export const getConfigContent = name =>
  get(`${CITY_SERVICE}/OMS.svc/W4_GetConfigContent?_version=9999`, {
    fileName: name,
  });

// 菜单拖拽
export const dragMenu = params =>
  get(`${CITY_SERVICE}/OMS.svc/P_DragMenu`, params);

// 获取产品列表
export const getProductList = params =>
  post(`${PUBLISH_SERVICE}/UserCenter/ProductList`, params);

// 新增或修改产品列表 Id为0时新增，Id大于0时修改
export const modifyProduct = params =>
  post(`${PUBLISH_SERVICE}/UserCenter/ModifyProduct`, params);

// 删除产品列表
export const delProductList = params =>
  get(`${PUBLISH_SERVICE}/UserCenter/DelProduct`, params);

/**
 * @新接口
 */
// 根据title获取网站配置
export const getWebSite = title =>
  get(`${PUBLISH_SERVICE}/WebSite/GetWebsite`, { title });
// 添加网站配置
export const addWebsite = params => {
  const obj = { ...params };
  Object.keys(obj).forEach(k => {
    if (typeof obj[k] === 'string') {
      obj[k] = obj[k].trim();
    }
  });
  return post(`${PUBLISH_SERVICE}/WebSite/AddWebsite`, obj);
};

export const editWebsite = params => {
  const obj = { ...params };
  Object.keys(obj).forEach(k => {
    if (typeof obj[k] === 'string') {
      obj[k] = obj[k].trim();
    }
  });
  return post(`${PUBLISH_SERVICE}/WebSite/EditWebsite`, obj);
};

// 删除网站
export const omsDeleteWebsite = client =>
  get(`${PUBLISH_SERVICE}/WebSite/DeleteWebsite`, { client });
